@@ -1,7 +1,8 @@
 /*
     meta.c -- handle the meta communication
-    Copyright (C) 2000-2006 Guus Sliepen <guus@tinc-vpn.org>,
+    Copyright (C) 2000-2009 Guus Sliepen <guus@tinc-vpn.org>,
                   2000-2005 Ivo Timmermans
+                  2006      Scott Lamb <slamb@slamb.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -13,11 +14,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-    $Id: meta.c 1471 2006-11-14 12:28:04Z guus $
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 #include "system.h"
@@ -34,14 +33,16 @@
 #include "utils.h"
 #include "xalloc.h"
 
-bool send_meta(connection_t *c, const char *buffer, int length)
-{
+bool send_meta(connection_t *c, const char *buffer, int length) {
 	int outlen;
 	int result;
 
-	cp();
+	if(!c) {
+		logger(LOG_ERR, "send_meta() called with NULL pointer!");
+		abort();
+	}
 
-	ifdebug(META) logger(LOG_DEBUG, _("Sending %d bytes of metadata to %s (%s)"), length,
+	ifdebug(META) logger(LOG_DEBUG, "Sending %d bytes of metadata to %s (%s)", length,
 			   c->name, c->hostname);
 
 	if(!c->outbuflen)
@@ -63,11 +64,11 @@ bool send_meta(connection_t *c, const char *buffer, int length)
 		result = EVP_EncryptUpdate(c->outctx, (unsigned char *)c->outbuf + c->outbufstart + c->outbuflen,
 				&outlen, (unsigned char *)buffer, length);
 		if(!result || outlen < length) {
-			logger(LOG_ERR, _("Error while encrypting metadata to %s (%s): %s"),
+			logger(LOG_ERR, "Error while encrypting metadata to %s (%s): %s",
 					c->name, c->hostname, ERR_error_string(ERR_get_error(), NULL));
 			return false;
 		} else if(outlen > length) {
-			logger(LOG_EMERG, _("Encrypted data too long! Heap corrupted!"));
+			logger(LOG_EMERG, "Encrypted data too long! Heap corrupted!");
 			abort();
 		}
 		c->outbuflen += outlen;
@@ -79,30 +80,27 @@ bool send_meta(connection_t *c, const char *buffer, int length)
 	return true;
 }
 
-bool flush_meta(connection_t *c)
-{
+bool flush_meta(connection_t *c) {
 	int result;
 	
-	ifdebug(META) logger(LOG_DEBUG, _("Flushing %d bytes to %s (%s)"),
+	ifdebug(META) logger(LOG_DEBUG, "Flushing %d bytes to %s (%s)",
 			 c->outbuflen, c->name, c->hostname);
 
 	while(c->outbuflen) {
 		result = send(c->socket, c->outbuf + c->outbufstart, c->outbuflen, 0);
 		if(result <= 0) {
 			if(!errno || errno == EPIPE) {
-				ifdebug(CONNECTIONS) logger(LOG_NOTICE, _("Connection closed by %s (%s)"),
+				ifdebug(CONNECTIONS) logger(LOG_NOTICE, "Connection closed by %s (%s)",
 						   c->name, c->hostname);
 			} else if(errno == EINTR) {
 				continue;
-#ifdef EWOULDBLOCK
-			} else if(errno == EWOULDBLOCK) {
-				ifdebug(CONNECTIONS) logger(LOG_DEBUG, _("Flushing %d bytes to %s (%s) would block"),
+			} else if(sockwouldblock(sockerrno)) {
+				ifdebug(CONNECTIONS) logger(LOG_DEBUG, "Flushing %d bytes to %s (%s) would block",
 						c->outbuflen, c->name, c->hostname);
 				return true;
-#endif
 			} else {
-				logger(LOG_ERR, _("Flushing meta data to %s (%s) failed: %s"), c->name,
-					   c->hostname, strerror(errno));
+				logger(LOG_ERR, "Flushing meta data to %s (%s) failed: %s", c->name,
+					   c->hostname, sockstrerror(sockerrno));
 			}
 
 			return false;
@@ -116,13 +114,10 @@ bool flush_meta(connection_t *c)
 	return true;
 }
 
-void broadcast_meta(connection_t *from, const char *buffer, int length)
-{
+void broadcast_meta(connection_t *from, const char *buffer, int length) {
 	avl_node_t *node;
 	connection_t *c;
 
-	cp();
-
 	for(node = connection_tree->head; node; node = node->next) {
 		c = node->data;
 
@@ -131,15 +126,12 @@ void broadcast_meta(connection_t *from, const char *buffer, int length)
 	}
 }
 
-bool receive_meta(connection_t *c)
-{
+bool receive_meta(connection_t *c) {
 	int oldlen, i, result;
 	int lenin, lenout, reqlen;
 	bool decrypted = false;
 	char inbuf[MAXBUFSIZE];
 
-	cp();
-
 	/* Strategy:
 	   - Read as much as possible from the TCP socket in one go.
 	   - Decrypt it.
@@ -153,13 +145,13 @@ bool receive_meta(connection_t *c)
 
 	if(lenin <= 0) {
 		if(!lenin || !errno) {
-			ifdebug(CONNECTIONS) logger(LOG_NOTICE, _("Connection closed by %s (%s)"),
+			ifdebug(CONNECTIONS) logger(LOG_NOTICE, "Connection closed by %s (%s)",
 					   c->name, c->hostname);
-		} else if(errno == EINTR)
+		} else if(sockwouldblock(sockerrno))
 			return true;
 		else
-			logger(LOG_ERR, _("Metadata socket read error for %s (%s): %s"),
-				   c->name, c->hostname, strerror(errno));
+			logger(LOG_ERR, "Metadata socket read error for %s (%s): %s",
+				   c->name, c->hostname, sockstrerror(sockerrno));
 
 		return false;
 	}
@@ -173,7 +165,7 @@ bool receive_meta(connection_t *c)
 		if(c->status.decryptin && !decrypted) {
 			result = EVP_DecryptUpdate(c->inctx, (unsigned char *)inbuf, &lenout, (unsigned char *)c->buffer + oldlen, lenin);
 			if(!result || lenout != lenin) {
-				logger(LOG_ERR, _("Error while decrypting metadata from %s (%s): %s"),
+				logger(LOG_ERR, "Error while decrypting metadata from %s (%s): %s",
 						c->name, c->hostname, ERR_error_string(ERR_get_error(), NULL));
 				return false;
 			}
@@ -226,12 +218,10 @@ bool receive_meta(connection_t *c)
 	}
 
 	if(c->buflen >= MAXBUFSIZE) {
-		logger(LOG_ERR, _("Metadata read buffer overflow for %s (%s)"),
+		logger(LOG_ERR, "Metadata read buffer overflow for %s (%s)",
 			   c->name, c->hostname);
 		return false;
 	}
 
-	c->last_ping_time = now;
-
 	return true;
 }
